Error

Enum Error 

#[non_exhaustive]
pub enum Error { Physical(Error), Symbol(Error), PageNotPresent(u64), PartialRead { addr: u64, requested: usize, got: usize, }, MissingSymbol(String), SizeMismatch { expected: usize, got: usize, }, ListCycle(usize), PagedOut { vaddr: u64, pagefile_num: u8, page_offset: u64, }, PrototypePte(u64), }
Error type for memf-core operations.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Physical(Error)

Physical memory read error.



Symbol(Error)

Symbol resolution error.



PageNotPresent(u64)

Page table entry not present (page fault).



PartialRead

Read crossed a page boundary and the next page is not mapped.

Fields

addr: u64

Virtual address of the read.

requested: usize

Bytes requested.

got: usize

Bytes actually read.



MissingSymbol(String)

A required symbol or field was not found.



SizeMismatch

Type size mismatch during Pod cast.

Fields

expected: usize

Expected size in bytes.

got: usize

Actual size available.



ListCycle(usize)

The list walk exceeded the maximum iteration count (cycle protection).



PagedOut

Page is in a pagefile that was not provided.

Fields

vaddr: u64

Virtual address of the faulting page.

pagefile_num: u8

Pagefile number (0 = pagefile.sys, 1-15 = secondary).

page_offset: u64

Page offset within the pagefile.



PrototypePte(u64)

Page uses a prototype PTE (shared section, not yet supported).